@@ -3,33 +3,32 @@
 import io
 import fnmatch
 import os
-import warnings
 import zipfile
+from functools import partial
+
+# Third party imports
+try:
+    import certifi
+except ImportError:
+    from ..vendor import certifi
 
 # Local imports
 from .. import http, paths
 from ..module import Module, ModuleSpec, parse_module_requirement, sort_modules
 from ..reporter import get_reporter
 from ..vendor import yaml
+from ..vendor.shotgun_api3 import Shotgun
+from ..vendor.cachetools import TTLCache, cachedmethod, keys
 from ..versions import parse_version
 from .base import Repo
 
-try:
-    from shotgun_api3 import Shotgun
-except ImportError:
-    warnings.warn(
-        'ShotgunRepo is unavailable.\n'
-        'Install the Shotgun API using pip:\n'
-        '    pip install git+git://github.com/shotgunsoftware/python-api.git'
-    )
-
 
 class ShotgunRepo(Repo):
     '''Use Shotgun's database as a Repo for modules.
 
     Requirements:
         A CustomNonProjectEntity named "Module" to be enabled via
-        Shotgun site-preferences.
+        Shotgun site-preferences with the following fields enabled:
 
         The following fields must be added to the "Module" entity.
           - archive       File/Link
@@ -39,6 +38,11 @@ class ShotgunRepo(Repo):
           - email         Text
           - version       Text
 
+        A CustomEntity named "Environment" to be enabled via
+        Shotgun site-preferences with the following fields enabled:
+          - engine        Text
+          - requires      Text
+
     Arguments:
         name (str): Name of this Repo
         module_entity (str): Name of Module entity (CustomNonProjectEntity01)
@@ -78,6 +82,7 @@ class ShotgunRepo(Repo):
                 base_url=base_url,
                 script_name=script_name,
                 api_key=api_key,
+                ca_certs=certifi.where(),
             )
 
         self.base_url = self._api.base_url
@@ -93,11 +98,16 @@ class ShotgunRepo(Repo):
             'sg_data',
         ]
         self.archive_fields = ['sg_archive', 'sg_archive_size']
+        self.cache = TTLCache(maxsize=10, ttl=60)
 
     @property
     def shotgun(self):
         return self._api
 
+    def clear_cache(self):
+        self.cache.clear()
+
+    @cachedmethod(lambda self: self.cache, key=partial(keys.hashkey, 'find'))
     def find(self, requirement):
         name, version = parse_module_requirement(requirement)
 
@@ -127,6 +137,7 @@ class ShotgunRepo(Repo):
 
         return sort_modules(module_specs, reverse=True)
 
+    @cachedmethod(lambda self: self.cache, key=partial(keys.hashkey, 'list'))
     def list(self):
         entities = self.shotgun.find(
             self.module_entity,
